# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SpringCloudAppCosmosDBAssociationArgs', 'SpringCloudAppCosmosDBAssociation']

@pulumi.input_type
class SpringCloudAppCosmosDBAssociationArgs:
    def __init__(__self__, *,
                 api_type: pulumi.Input[str],
                 cosmosdb_access_key: pulumi.Input[str],
                 cosmosdb_account_id: pulumi.Input[str],
                 spring_cloud_app_id: pulumi.Input[str],
                 cosmosdb_cassandra_keyspace_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_gremlin_database_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_gremlin_graph_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_mongo_database_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_sql_database_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SpringCloudAppCosmosDBAssociation resource.
        :param pulumi.Input[str] api_type: Specifies the API type which should be used when connecting to the CosmosDB Account. Possible values are `cassandra`, `gremlin`, `mongo`, `sql` or `table`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] cosmosdb_access_key: Specifies the CosmosDB Account access key.
        :param pulumi.Input[str] cosmosdb_account_id: Specifies the ID of the CosmosDB Account. Changing this forces a new resource to be created.
        :param pulumi.Input[str] spring_cloud_app_id: Specifies the ID of the Spring Cloud Application where this Association is created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] cosmosdb_cassandra_keyspace_name: Specifies the name of the Cassandra Keyspace which the Spring Cloud App should be associated with. Should only be set when `api_type` is `cassandra`.
        :param pulumi.Input[str] cosmosdb_gremlin_database_name: Specifies the name of the Gremlin Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        :param pulumi.Input[str] cosmosdb_gremlin_graph_name: Specifies the name of the Gremlin Graph which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        :param pulumi.Input[str] cosmosdb_mongo_database_name: Specifies the name of the Mongo Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `mongo`.
        :param pulumi.Input[str] cosmosdb_sql_database_name: Specifies the name of the SQL Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `sql`.
        :param pulumi.Input[str] name: Specifies the name of the Spring Cloud Application Association. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "api_type", api_type)
        pulumi.set(__self__, "cosmosdb_access_key", cosmosdb_access_key)
        pulumi.set(__self__, "cosmosdb_account_id", cosmosdb_account_id)
        pulumi.set(__self__, "spring_cloud_app_id", spring_cloud_app_id)
        if cosmosdb_cassandra_keyspace_name is not None:
            pulumi.set(__self__, "cosmosdb_cassandra_keyspace_name", cosmosdb_cassandra_keyspace_name)
        if cosmosdb_gremlin_database_name is not None:
            pulumi.set(__self__, "cosmosdb_gremlin_database_name", cosmosdb_gremlin_database_name)
        if cosmosdb_gremlin_graph_name is not None:
            pulumi.set(__self__, "cosmosdb_gremlin_graph_name", cosmosdb_gremlin_graph_name)
        if cosmosdb_mongo_database_name is not None:
            pulumi.set(__self__, "cosmosdb_mongo_database_name", cosmosdb_mongo_database_name)
        if cosmosdb_sql_database_name is not None:
            pulumi.set(__self__, "cosmosdb_sql_database_name", cosmosdb_sql_database_name)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="apiType")
    def api_type(self) -> pulumi.Input[str]:
        """
        Specifies the API type which should be used when connecting to the CosmosDB Account. Possible values are `cassandra`, `gremlin`, `mongo`, `sql` or `table`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_type")

    @api_type.setter
    def api_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "api_type", value)

    @property
    @pulumi.getter(name="cosmosdbAccessKey")
    def cosmosdb_access_key(self) -> pulumi.Input[str]:
        """
        Specifies the CosmosDB Account access key.
        """
        return pulumi.get(self, "cosmosdb_access_key")

    @cosmosdb_access_key.setter
    def cosmosdb_access_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "cosmosdb_access_key", value)

    @property
    @pulumi.getter(name="cosmosdbAccountId")
    def cosmosdb_account_id(self) -> pulumi.Input[str]:
        """
        Specifies the ID of the CosmosDB Account. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "cosmosdb_account_id")

    @cosmosdb_account_id.setter
    def cosmosdb_account_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "cosmosdb_account_id", value)

    @property
    @pulumi.getter(name="springCloudAppId")
    def spring_cloud_app_id(self) -> pulumi.Input[str]:
        """
        Specifies the ID of the Spring Cloud Application where this Association is created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "spring_cloud_app_id")

    @spring_cloud_app_id.setter
    def spring_cloud_app_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "spring_cloud_app_id", value)

    @property
    @pulumi.getter(name="cosmosdbCassandraKeyspaceName")
    def cosmosdb_cassandra_keyspace_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Cassandra Keyspace which the Spring Cloud App should be associated with. Should only be set when `api_type` is `cassandra`.
        """
        return pulumi.get(self, "cosmosdb_cassandra_keyspace_name")

    @cosmosdb_cassandra_keyspace_name.setter
    def cosmosdb_cassandra_keyspace_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_cassandra_keyspace_name", value)

    @property
    @pulumi.getter(name="cosmosdbGremlinDatabaseName")
    def cosmosdb_gremlin_database_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Gremlin Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        """
        return pulumi.get(self, "cosmosdb_gremlin_database_name")

    @cosmosdb_gremlin_database_name.setter
    def cosmosdb_gremlin_database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_gremlin_database_name", value)

    @property
    @pulumi.getter(name="cosmosdbGremlinGraphName")
    def cosmosdb_gremlin_graph_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Gremlin Graph which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        """
        return pulumi.get(self, "cosmosdb_gremlin_graph_name")

    @cosmosdb_gremlin_graph_name.setter
    def cosmosdb_gremlin_graph_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_gremlin_graph_name", value)

    @property
    @pulumi.getter(name="cosmosdbMongoDatabaseName")
    def cosmosdb_mongo_database_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Mongo Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `mongo`.
        """
        return pulumi.get(self, "cosmosdb_mongo_database_name")

    @cosmosdb_mongo_database_name.setter
    def cosmosdb_mongo_database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_mongo_database_name", value)

    @property
    @pulumi.getter(name="cosmosdbSqlDatabaseName")
    def cosmosdb_sql_database_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the SQL Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `sql`.
        """
        return pulumi.get(self, "cosmosdb_sql_database_name")

    @cosmosdb_sql_database_name.setter
    def cosmosdb_sql_database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_sql_database_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Spring Cloud Application Association. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _SpringCloudAppCosmosDBAssociationState:
    def __init__(__self__, *,
                 api_type: Optional[pulumi.Input[str]] = None,
                 cosmosdb_access_key: Optional[pulumi.Input[str]] = None,
                 cosmosdb_account_id: Optional[pulumi.Input[str]] = None,
                 cosmosdb_cassandra_keyspace_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_gremlin_database_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_gremlin_graph_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_mongo_database_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_sql_database_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 spring_cloud_app_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SpringCloudAppCosmosDBAssociation resources.
        :param pulumi.Input[str] api_type: Specifies the API type which should be used when connecting to the CosmosDB Account. Possible values are `cassandra`, `gremlin`, `mongo`, `sql` or `table`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] cosmosdb_access_key: Specifies the CosmosDB Account access key.
        :param pulumi.Input[str] cosmosdb_account_id: Specifies the ID of the CosmosDB Account. Changing this forces a new resource to be created.
        :param pulumi.Input[str] cosmosdb_cassandra_keyspace_name: Specifies the name of the Cassandra Keyspace which the Spring Cloud App should be associated with. Should only be set when `api_type` is `cassandra`.
        :param pulumi.Input[str] cosmosdb_gremlin_database_name: Specifies the name of the Gremlin Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        :param pulumi.Input[str] cosmosdb_gremlin_graph_name: Specifies the name of the Gremlin Graph which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        :param pulumi.Input[str] cosmosdb_mongo_database_name: Specifies the name of the Mongo Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `mongo`.
        :param pulumi.Input[str] cosmosdb_sql_database_name: Specifies the name of the SQL Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `sql`.
        :param pulumi.Input[str] name: Specifies the name of the Spring Cloud Application Association. Changing this forces a new resource to be created.
        :param pulumi.Input[str] spring_cloud_app_id: Specifies the ID of the Spring Cloud Application where this Association is created. Changing this forces a new resource to be created.
        """
        if api_type is not None:
            pulumi.set(__self__, "api_type", api_type)
        if cosmosdb_access_key is not None:
            pulumi.set(__self__, "cosmosdb_access_key", cosmosdb_access_key)
        if cosmosdb_account_id is not None:
            pulumi.set(__self__, "cosmosdb_account_id", cosmosdb_account_id)
        if cosmosdb_cassandra_keyspace_name is not None:
            pulumi.set(__self__, "cosmosdb_cassandra_keyspace_name", cosmosdb_cassandra_keyspace_name)
        if cosmosdb_gremlin_database_name is not None:
            pulumi.set(__self__, "cosmosdb_gremlin_database_name", cosmosdb_gremlin_database_name)
        if cosmosdb_gremlin_graph_name is not None:
            pulumi.set(__self__, "cosmosdb_gremlin_graph_name", cosmosdb_gremlin_graph_name)
        if cosmosdb_mongo_database_name is not None:
            pulumi.set(__self__, "cosmosdb_mongo_database_name", cosmosdb_mongo_database_name)
        if cosmosdb_sql_database_name is not None:
            pulumi.set(__self__, "cosmosdb_sql_database_name", cosmosdb_sql_database_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if spring_cloud_app_id is not None:
            pulumi.set(__self__, "spring_cloud_app_id", spring_cloud_app_id)

    @property
    @pulumi.getter(name="apiType")
    def api_type(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the API type which should be used when connecting to the CosmosDB Account. Possible values are `cassandra`, `gremlin`, `mongo`, `sql` or `table`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_type")

    @api_type.setter
    def api_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_type", value)

    @property
    @pulumi.getter(name="cosmosdbAccessKey")
    def cosmosdb_access_key(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the CosmosDB Account access key.
        """
        return pulumi.get(self, "cosmosdb_access_key")

    @cosmosdb_access_key.setter
    def cosmosdb_access_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_access_key", value)

    @property
    @pulumi.getter(name="cosmosdbAccountId")
    def cosmosdb_account_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the ID of the CosmosDB Account. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "cosmosdb_account_id")

    @cosmosdb_account_id.setter
    def cosmosdb_account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_account_id", value)

    @property
    @pulumi.getter(name="cosmosdbCassandraKeyspaceName")
    def cosmosdb_cassandra_keyspace_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Cassandra Keyspace which the Spring Cloud App should be associated with. Should only be set when `api_type` is `cassandra`.
        """
        return pulumi.get(self, "cosmosdb_cassandra_keyspace_name")

    @cosmosdb_cassandra_keyspace_name.setter
    def cosmosdb_cassandra_keyspace_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_cassandra_keyspace_name", value)

    @property
    @pulumi.getter(name="cosmosdbGremlinDatabaseName")
    def cosmosdb_gremlin_database_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Gremlin Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        """
        return pulumi.get(self, "cosmosdb_gremlin_database_name")

    @cosmosdb_gremlin_database_name.setter
    def cosmosdb_gremlin_database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_gremlin_database_name", value)

    @property
    @pulumi.getter(name="cosmosdbGremlinGraphName")
    def cosmosdb_gremlin_graph_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Gremlin Graph which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        """
        return pulumi.get(self, "cosmosdb_gremlin_graph_name")

    @cosmosdb_gremlin_graph_name.setter
    def cosmosdb_gremlin_graph_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_gremlin_graph_name", value)

    @property
    @pulumi.getter(name="cosmosdbMongoDatabaseName")
    def cosmosdb_mongo_database_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Mongo Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `mongo`.
        """
        return pulumi.get(self, "cosmosdb_mongo_database_name")

    @cosmosdb_mongo_database_name.setter
    def cosmosdb_mongo_database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_mongo_database_name", value)

    @property
    @pulumi.getter(name="cosmosdbSqlDatabaseName")
    def cosmosdb_sql_database_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the SQL Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `sql`.
        """
        return pulumi.get(self, "cosmosdb_sql_database_name")

    @cosmosdb_sql_database_name.setter
    def cosmosdb_sql_database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_sql_database_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Spring Cloud Application Association. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="springCloudAppId")
    def spring_cloud_app_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the ID of the Spring Cloud Application where this Association is created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "spring_cloud_app_id")

    @spring_cloud_app_id.setter
    def spring_cloud_app_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "spring_cloud_app_id", value)


class SpringCloudAppCosmosDBAssociation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_type: Optional[pulumi.Input[str]] = None,
                 cosmosdb_access_key: Optional[pulumi.Input[str]] = None,
                 cosmosdb_account_id: Optional[pulumi.Input[str]] = None,
                 cosmosdb_cassandra_keyspace_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_gremlin_database_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_gremlin_graph_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_mongo_database_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_sql_database_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 spring_cloud_app_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Associates a Spring Cloud Application with a CosmosDB Account.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_spring_cloud_service = azure.appplatform.SpringCloudService("example",
            name="example-springcloud",
            resource_group_name=example.name,
            location=example.location)
        example_spring_cloud_app = azure.appplatform.SpringCloudApp("example",
            name="example-springcloudapp",
            resource_group_name=example.name,
            service_name=example_spring_cloud_service.name)
        example_account = azure.cosmosdb.Account("example",
            name="example-cosmosdb-account",
            location=example.location,
            resource_group_name=example.name,
            offer_type="Standard",
            kind="GlobalDocumentDB",
            consistency_policy={
                "consistency_level": "Strong",
            },
            geo_locations=[{
                "location": example.location,
                "failover_priority": 0,
            }])
        example_spring_cloud_app_cosmos_dbassociation = azure.appplatform.SpringCloudAppCosmosDBAssociation("example",
            name="example-bind",
            spring_cloud_app_id=example_spring_cloud_app.id,
            cosmosdb_account_id=example_account.id,
            api_type="table",
            cosmosdb_access_key=example_account.primary_key)
        ```

        ## Import

        Spring Cloud Application CosmosDB Association can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:appplatform/springCloudAppCosmosDBAssociation:SpringCloudAppCosmosDBAssociation example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourcegroup1/providers/Microsoft.AppPlatform/spring/service1/apps/app1/bindings/bind1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_type: Specifies the API type which should be used when connecting to the CosmosDB Account. Possible values are `cassandra`, `gremlin`, `mongo`, `sql` or `table`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] cosmosdb_access_key: Specifies the CosmosDB Account access key.
        :param pulumi.Input[str] cosmosdb_account_id: Specifies the ID of the CosmosDB Account. Changing this forces a new resource to be created.
        :param pulumi.Input[str] cosmosdb_cassandra_keyspace_name: Specifies the name of the Cassandra Keyspace which the Spring Cloud App should be associated with. Should only be set when `api_type` is `cassandra`.
        :param pulumi.Input[str] cosmosdb_gremlin_database_name: Specifies the name of the Gremlin Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        :param pulumi.Input[str] cosmosdb_gremlin_graph_name: Specifies the name of the Gremlin Graph which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        :param pulumi.Input[str] cosmosdb_mongo_database_name: Specifies the name of the Mongo Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `mongo`.
        :param pulumi.Input[str] cosmosdb_sql_database_name: Specifies the name of the SQL Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `sql`.
        :param pulumi.Input[str] name: Specifies the name of the Spring Cloud Application Association. Changing this forces a new resource to be created.
        :param pulumi.Input[str] spring_cloud_app_id: Specifies the ID of the Spring Cloud Application where this Association is created. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SpringCloudAppCosmosDBAssociationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Associates a Spring Cloud Application with a CosmosDB Account.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_spring_cloud_service = azure.appplatform.SpringCloudService("example",
            name="example-springcloud",
            resource_group_name=example.name,
            location=example.location)
        example_spring_cloud_app = azure.appplatform.SpringCloudApp("example",
            name="example-springcloudapp",
            resource_group_name=example.name,
            service_name=example_spring_cloud_service.name)
        example_account = azure.cosmosdb.Account("example",
            name="example-cosmosdb-account",
            location=example.location,
            resource_group_name=example.name,
            offer_type="Standard",
            kind="GlobalDocumentDB",
            consistency_policy={
                "consistency_level": "Strong",
            },
            geo_locations=[{
                "location": example.location,
                "failover_priority": 0,
            }])
        example_spring_cloud_app_cosmos_dbassociation = azure.appplatform.SpringCloudAppCosmosDBAssociation("example",
            name="example-bind",
            spring_cloud_app_id=example_spring_cloud_app.id,
            cosmosdb_account_id=example_account.id,
            api_type="table",
            cosmosdb_access_key=example_account.primary_key)
        ```

        ## Import

        Spring Cloud Application CosmosDB Association can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:appplatform/springCloudAppCosmosDBAssociation:SpringCloudAppCosmosDBAssociation example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourcegroup1/providers/Microsoft.AppPlatform/spring/service1/apps/app1/bindings/bind1
        ```

        :param str resource_name: The name of the resource.
        :param SpringCloudAppCosmosDBAssociationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SpringCloudAppCosmosDBAssociationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_type: Optional[pulumi.Input[str]] = None,
                 cosmosdb_access_key: Optional[pulumi.Input[str]] = None,
                 cosmosdb_account_id: Optional[pulumi.Input[str]] = None,
                 cosmosdb_cassandra_keyspace_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_gremlin_database_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_gremlin_graph_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_mongo_database_name: Optional[pulumi.Input[str]] = None,
                 cosmosdb_sql_database_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 spring_cloud_app_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SpringCloudAppCosmosDBAssociationArgs.__new__(SpringCloudAppCosmosDBAssociationArgs)

            if api_type is None and not opts.urn:
                raise TypeError("Missing required property 'api_type'")
            __props__.__dict__["api_type"] = api_type
            if cosmosdb_access_key is None and not opts.urn:
                raise TypeError("Missing required property 'cosmosdb_access_key'")
            __props__.__dict__["cosmosdb_access_key"] = cosmosdb_access_key
            if cosmosdb_account_id is None and not opts.urn:
                raise TypeError("Missing required property 'cosmosdb_account_id'")
            __props__.__dict__["cosmosdb_account_id"] = cosmosdb_account_id
            __props__.__dict__["cosmosdb_cassandra_keyspace_name"] = cosmosdb_cassandra_keyspace_name
            __props__.__dict__["cosmosdb_gremlin_database_name"] = cosmosdb_gremlin_database_name
            __props__.__dict__["cosmosdb_gremlin_graph_name"] = cosmosdb_gremlin_graph_name
            __props__.__dict__["cosmosdb_mongo_database_name"] = cosmosdb_mongo_database_name
            __props__.__dict__["cosmosdb_sql_database_name"] = cosmosdb_sql_database_name
            __props__.__dict__["name"] = name
            if spring_cloud_app_id is None and not opts.urn:
                raise TypeError("Missing required property 'spring_cloud_app_id'")
            __props__.__dict__["spring_cloud_app_id"] = spring_cloud_app_id
        super(SpringCloudAppCosmosDBAssociation, __self__).__init__(
            'azure:appplatform/springCloudAppCosmosDBAssociation:SpringCloudAppCosmosDBAssociation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_type: Optional[pulumi.Input[str]] = None,
            cosmosdb_access_key: Optional[pulumi.Input[str]] = None,
            cosmosdb_account_id: Optional[pulumi.Input[str]] = None,
            cosmosdb_cassandra_keyspace_name: Optional[pulumi.Input[str]] = None,
            cosmosdb_gremlin_database_name: Optional[pulumi.Input[str]] = None,
            cosmosdb_gremlin_graph_name: Optional[pulumi.Input[str]] = None,
            cosmosdb_mongo_database_name: Optional[pulumi.Input[str]] = None,
            cosmosdb_sql_database_name: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            spring_cloud_app_id: Optional[pulumi.Input[str]] = None) -> 'SpringCloudAppCosmosDBAssociation':
        """
        Get an existing SpringCloudAppCosmosDBAssociation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_type: Specifies the API type which should be used when connecting to the CosmosDB Account. Possible values are `cassandra`, `gremlin`, `mongo`, `sql` or `table`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] cosmosdb_access_key: Specifies the CosmosDB Account access key.
        :param pulumi.Input[str] cosmosdb_account_id: Specifies the ID of the CosmosDB Account. Changing this forces a new resource to be created.
        :param pulumi.Input[str] cosmosdb_cassandra_keyspace_name: Specifies the name of the Cassandra Keyspace which the Spring Cloud App should be associated with. Should only be set when `api_type` is `cassandra`.
        :param pulumi.Input[str] cosmosdb_gremlin_database_name: Specifies the name of the Gremlin Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        :param pulumi.Input[str] cosmosdb_gremlin_graph_name: Specifies the name of the Gremlin Graph which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        :param pulumi.Input[str] cosmosdb_mongo_database_name: Specifies the name of the Mongo Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `mongo`.
        :param pulumi.Input[str] cosmosdb_sql_database_name: Specifies the name of the SQL Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `sql`.
        :param pulumi.Input[str] name: Specifies the name of the Spring Cloud Application Association. Changing this forces a new resource to be created.
        :param pulumi.Input[str] spring_cloud_app_id: Specifies the ID of the Spring Cloud Application where this Association is created. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SpringCloudAppCosmosDBAssociationState.__new__(_SpringCloudAppCosmosDBAssociationState)

        __props__.__dict__["api_type"] = api_type
        __props__.__dict__["cosmosdb_access_key"] = cosmosdb_access_key
        __props__.__dict__["cosmosdb_account_id"] = cosmosdb_account_id
        __props__.__dict__["cosmosdb_cassandra_keyspace_name"] = cosmosdb_cassandra_keyspace_name
        __props__.__dict__["cosmosdb_gremlin_database_name"] = cosmosdb_gremlin_database_name
        __props__.__dict__["cosmosdb_gremlin_graph_name"] = cosmosdb_gremlin_graph_name
        __props__.__dict__["cosmosdb_mongo_database_name"] = cosmosdb_mongo_database_name
        __props__.__dict__["cosmosdb_sql_database_name"] = cosmosdb_sql_database_name
        __props__.__dict__["name"] = name
        __props__.__dict__["spring_cloud_app_id"] = spring_cloud_app_id
        return SpringCloudAppCosmosDBAssociation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="apiType")
    def api_type(self) -> pulumi.Output[str]:
        """
        Specifies the API type which should be used when connecting to the CosmosDB Account. Possible values are `cassandra`, `gremlin`, `mongo`, `sql` or `table`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_type")

    @property
    @pulumi.getter(name="cosmosdbAccessKey")
    def cosmosdb_access_key(self) -> pulumi.Output[str]:
        """
        Specifies the CosmosDB Account access key.
        """
        return pulumi.get(self, "cosmosdb_access_key")

    @property
    @pulumi.getter(name="cosmosdbAccountId")
    def cosmosdb_account_id(self) -> pulumi.Output[str]:
        """
        Specifies the ID of the CosmosDB Account. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "cosmosdb_account_id")

    @property
    @pulumi.getter(name="cosmosdbCassandraKeyspaceName")
    def cosmosdb_cassandra_keyspace_name(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the name of the Cassandra Keyspace which the Spring Cloud App should be associated with. Should only be set when `api_type` is `cassandra`.
        """
        return pulumi.get(self, "cosmosdb_cassandra_keyspace_name")

    @property
    @pulumi.getter(name="cosmosdbGremlinDatabaseName")
    def cosmosdb_gremlin_database_name(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the name of the Gremlin Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        """
        return pulumi.get(self, "cosmosdb_gremlin_database_name")

    @property
    @pulumi.getter(name="cosmosdbGremlinGraphName")
    def cosmosdb_gremlin_graph_name(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the name of the Gremlin Graph which the Spring Cloud App should be associated with. Should only be set when `api_type` is `gremlin`.
        """
        return pulumi.get(self, "cosmosdb_gremlin_graph_name")

    @property
    @pulumi.getter(name="cosmosdbMongoDatabaseName")
    def cosmosdb_mongo_database_name(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the name of the Mongo Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `mongo`.
        """
        return pulumi.get(self, "cosmosdb_mongo_database_name")

    @property
    @pulumi.getter(name="cosmosdbSqlDatabaseName")
    def cosmosdb_sql_database_name(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the name of the SQL Database which the Spring Cloud App should be associated with. Should only be set when `api_type` is `sql`.
        """
        return pulumi.get(self, "cosmosdb_sql_database_name")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Specifies the name of the Spring Cloud Application Association. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="springCloudAppId")
    def spring_cloud_app_id(self) -> pulumi.Output[str]:
        """
        Specifies the ID of the Spring Cloud Application where this Association is created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "spring_cloud_app_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ApplicationArgs', 'Application']

@pulumi.input_type
class ApplicationArgs:
    def __init__(__self__, *,
                 application_group_id: pulumi.Input[str],
                 command_line_argument_policy: pulumi.Input[str],
                 path: pulumi.Input[str],
                 command_line_arguments: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 friendly_name: Optional[pulumi.Input[str]] = None,
                 icon_index: Optional[pulumi.Input[int]] = None,
                 icon_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 show_in_portal: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Application resource.
        :param pulumi.Input[str] application_group_id: Resource ID for a Virtual Desktop Application Group to associate with the Virtual Desktop Application. Changing this forces a new resource to be created.
        :param pulumi.Input[str] command_line_argument_policy: Specifies whether this published application can be launched with command line arguments provided by the client, command line arguments specified at publish time, or no command line arguments at all. Possible values include: `DoNotAllow`, `Allow`, `Require`.
        :param pulumi.Input[str] path: The file path location of the app on the Virtual Desktop OS.
        :param pulumi.Input[str] command_line_arguments: Command Line Arguments for Virtual Desktop Application.
        :param pulumi.Input[str] description: Option to set a description for the Virtual Desktop Application.
        :param pulumi.Input[str] friendly_name: Option to set a friendly name for the Virtual Desktop Application.
        :param pulumi.Input[int] icon_index: The index of the icon you wish to use.
        :param pulumi.Input[str] icon_path: Specifies the path for an icon which will be used for this Virtual Desktop Application.
        :param pulumi.Input[str] name: The name of the Virtual Desktop Application. Changing the name forces a new resource to be created.
        :param pulumi.Input[bool] show_in_portal: Specifies whether to show the RemoteApp program in the RD Web Access server.
        """
        pulumi.set(__self__, "application_group_id", application_group_id)
        pulumi.set(__self__, "command_line_argument_policy", command_line_argument_policy)
        pulumi.set(__self__, "path", path)
        if command_line_arguments is not None:
            pulumi.set(__self__, "command_line_arguments", command_line_arguments)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if friendly_name is not None:
            pulumi.set(__self__, "friendly_name", friendly_name)
        if icon_index is not None:
            pulumi.set(__self__, "icon_index", icon_index)
        if icon_path is not None:
            pulumi.set(__self__, "icon_path", icon_path)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if show_in_portal is not None:
            pulumi.set(__self__, "show_in_portal", show_in_portal)

    @property
    @pulumi.getter(name="applicationGroupId")
    def application_group_id(self) -> pulumi.Input[str]:
        """
        Resource ID for a Virtual Desktop Application Group to associate with the Virtual Desktop Application. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_group_id")

    @application_group_id.setter
    def application_group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "application_group_id", value)

    @property
    @pulumi.getter(name="commandLineArgumentPolicy")
    def command_line_argument_policy(self) -> pulumi.Input[str]:
        """
        Specifies whether this published application can be launched with command line arguments provided by the client, command line arguments specified at publish time, or no command line arguments at all. Possible values include: `DoNotAllow`, `Allow`, `Require`.
        """
        return pulumi.get(self, "command_line_argument_policy")

    @command_line_argument_policy.setter
    def command_line_argument_policy(self, value: pulumi.Input[str]):
        pulumi.set(self, "command_line_argument_policy", value)

    @property
    @pulumi.getter
    def path(self) -> pulumi.Input[str]:
        """
        The file path location of the app on the Virtual Desktop OS.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[str]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter(name="commandLineArguments")
    def command_line_arguments(self) -> Optional[pulumi.Input[str]]:
        """
        Command Line Arguments for Virtual Desktop Application.
        """
        return pulumi.get(self, "command_line_arguments")

    @command_line_arguments.setter
    def command_line_arguments(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "command_line_arguments", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Option to set a description for the Virtual Desktop Application.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="friendlyName")
    def friendly_name(self) -> Optional[pulumi.Input[str]]:
        """
        Option to set a friendly name for the Virtual Desktop Application.
        """
        return pulumi.get(self, "friendly_name")

    @friendly_name.setter
    def friendly_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "friendly_name", value)

    @property
    @pulumi.getter(name="iconIndex")
    def icon_index(self) -> Optional[pulumi.Input[int]]:
        """
        The index of the icon you wish to use.
        """
        return pulumi.get(self, "icon_index")

    @icon_index.setter
    def icon_index(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "icon_index", value)

    @property
    @pulumi.getter(name="iconPath")
    def icon_path(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the path for an icon which will be used for this Virtual Desktop Application.
        """
        return pulumi.get(self, "icon_path")

    @icon_path.setter
    def icon_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "icon_path", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Virtual Desktop Application. Changing the name forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="showInPortal")
    def show_in_portal(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to show the RemoteApp program in the RD Web Access server.
        """
        return pulumi.get(self, "show_in_portal")

    @show_in_portal.setter
    def show_in_portal(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "show_in_portal", value)


@pulumi.input_type
class _ApplicationState:
    def __init__(__self__, *,
                 application_group_id: Optional[pulumi.Input[str]] = None,
                 command_line_argument_policy: Optional[pulumi.Input[str]] = None,
                 command_line_arguments: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 friendly_name: Optional[pulumi.Input[str]] = None,
                 icon_index: Optional[pulumi.Input[int]] = None,
                 icon_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 show_in_portal: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering Application resources.
        :param pulumi.Input[str] application_group_id: Resource ID for a Virtual Desktop Application Group to associate with the Virtual Desktop Application. Changing this forces a new resource to be created.
        :param pulumi.Input[str] command_line_argument_policy: Specifies whether this published application can be launched with command line arguments provided by the client, command line arguments specified at publish time, or no command line arguments at all. Possible values include: `DoNotAllow`, `Allow`, `Require`.
        :param pulumi.Input[str] command_line_arguments: Command Line Arguments for Virtual Desktop Application.
        :param pulumi.Input[str] description: Option to set a description for the Virtual Desktop Application.
        :param pulumi.Input[str] friendly_name: Option to set a friendly name for the Virtual Desktop Application.
        :param pulumi.Input[int] icon_index: The index of the icon you wish to use.
        :param pulumi.Input[str] icon_path: Specifies the path for an icon which will be used for this Virtual Desktop Application.
        :param pulumi.Input[str] name: The name of the Virtual Desktop Application. Changing the name forces a new resource to be created.
        :param pulumi.Input[str] path: The file path location of the app on the Virtual Desktop OS.
        :param pulumi.Input[bool] show_in_portal: Specifies whether to show the RemoteApp program in the RD Web Access server.
        """
        if application_group_id is not None:
            pulumi.set(__self__, "application_group_id", application_group_id)
        if command_line_argument_policy is not None:
            pulumi.set(__self__, "command_line_argument_policy", command_line_argument_policy)
        if command_line_arguments is not None:
            pulumi.set(__self__, "command_line_arguments", command_line_arguments)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if friendly_name is not None:
            pulumi.set(__self__, "friendly_name", friendly_name)
        if icon_index is not None:
            pulumi.set(__self__, "icon_index", icon_index)
        if icon_path is not None:
            pulumi.set(__self__, "icon_path", icon_path)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if show_in_portal is not None:
            pulumi.set(__self__, "show_in_portal", show_in_portal)

    @property
    @pulumi.getter(name="applicationGroupId")
    def application_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        Resource ID for a Virtual Desktop Application Group to associate with the Virtual Desktop Application. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_group_id")

    @application_group_id.setter
    def application_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_group_id", value)

    @property
    @pulumi.getter(name="commandLineArgumentPolicy")
    def command_line_argument_policy(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether this published application can be launched with command line arguments provided by the client, command line arguments specified at publish time, or no command line arguments at all. Possible values include: `DoNotAllow`, `Allow`, `Require`.
        """
        return pulumi.get(self, "command_line_argument_policy")

    @command_line_argument_policy.setter
    def command_line_argument_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "command_line_argument_policy", value)

    @property
    @pulumi.getter(name="commandLineArguments")
    def command_line_arguments(self) -> Optional[pulumi.Input[str]]:
        """
        Command Line Arguments for Virtual Desktop Application.
        """
        return pulumi.get(self, "command_line_arguments")

    @command_line_arguments.setter
    def command_line_arguments(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "command_line_arguments", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Option to set a description for the Virtual Desktop Application.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="friendlyName")
    def friendly_name(self) -> Optional[pulumi.Input[str]]:
        """
        Option to set a friendly name for the Virtual Desktop Application.
        """
        return pulumi.get(self, "friendly_name")

    @friendly_name.setter
    def friendly_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "friendly_name", value)

    @property
    @pulumi.getter(name="iconIndex")
    def icon_index(self) -> Optional[pulumi.Input[int]]:
        """
        The index of the icon you wish to use.
        """
        return pulumi.get(self, "icon_index")

    @icon_index.setter
    def icon_index(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "icon_index", value)

    @property
    @pulumi.getter(name="iconPath")
    def icon_path(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the path for an icon which will be used for this Virtual Desktop Application.
        """
        return pulumi.get(self, "icon_path")

    @icon_path.setter
    def icon_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "icon_path", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Virtual Desktop Application. Changing the name forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        The file path location of the app on the Virtual Desktop OS.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter(name="showInPortal")
    def show_in_portal(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to show the RemoteApp program in the RD Web Access server.
        """
        return pulumi.get(self, "show_in_portal")

    @show_in_portal.setter
    def show_in_portal(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "show_in_portal", value)


class Application(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_group_id: Optional[pulumi.Input[str]] = None,
                 command_line_argument_policy: Optional[pulumi.Input[str]] = None,
                 command_line_arguments: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 friendly_name: Optional[pulumi.Input[str]] = None,
                 icon_index: Optional[pulumi.Input[int]] = None,
                 icon_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 show_in_portal: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Manages a Virtual Desktop Application.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="rg-example-virtualdesktop",
            location="West Europe")
        pooledbreadthfirst = azure.desktopvirtualization.HostPool("pooledbreadthfirst",
            name="pooledbreadthfirst",
            location=example.location,
            resource_group_name=example.name,
            type="Pooled",
            load_balancer_type="BreadthFirst")
        personalautomatic = azure.desktopvirtualization.HostPool("personalautomatic",
            name="personalautomatic",
            location=example.location,
            resource_group_name=example.name,
            type="Personal",
            personal_desktop_assignment_type="Automatic",
            load_balancer_type="BreadthFirst")
        remoteapp = azure.desktopvirtualization.ApplicationGroup("remoteapp",
            name="acctag",
            location=example.location,
            resource_group_name=example.name,
            type="RemoteApp",
            host_pool_id=pooledbreadthfirst.id,
            friendly_name="TestAppGroup",
            description="Acceptance Test: An application group")
        chrome = azure.desktopvirtualization.Application("chrome",
            name="googlechrome",
            application_group_id=remoteapp.id,
            friendly_name="Google Chrome",
            description="Chromium based web browser",
            path="C:\\\\Program Files\\\\Google\\\\Chrome\\\\Application\\\\chrome.exe",
            command_line_argument_policy="DoNotAllow",
            command_line_arguments="--incognito",
            show_in_portal=False,
            icon_path="C:\\\\Program Files\\\\Google\\\\Chrome\\\\Application\\\\chrome.exe",
            icon_index=0)
        ```

        ## Import

        Virtual Desktop Application can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:desktopvirtualization/application:Application example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/myGroup1/providers/Microsoft.DesktopVirtualization/applicationGroups/myapplicationgroup/applications/myapplication
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_group_id: Resource ID for a Virtual Desktop Application Group to associate with the Virtual Desktop Application. Changing this forces a new resource to be created.
        :param pulumi.Input[str] command_line_argument_policy: Specifies whether this published application can be launched with command line arguments provided by the client, command line arguments specified at publish time, or no command line arguments at all. Possible values include: `DoNotAllow`, `Allow`, `Require`.
        :param pulumi.Input[str] command_line_arguments: Command Line Arguments for Virtual Desktop Application.
        :param pulumi.Input[str] description: Option to set a description for the Virtual Desktop Application.
        :param pulumi.Input[str] friendly_name: Option to set a friendly name for the Virtual Desktop Application.
        :param pulumi.Input[int] icon_index: The index of the icon you wish to use.
        :param pulumi.Input[str] icon_path: Specifies the path for an icon which will be used for this Virtual Desktop Application.
        :param pulumi.Input[str] name: The name of the Virtual Desktop Application. Changing the name forces a new resource to be created.
        :param pulumi.Input[str] path: The file path location of the app on the Virtual Desktop OS.
        :param pulumi.Input[bool] show_in_portal: Specifies whether to show the RemoteApp program in the RD Web Access server.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApplicationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Virtual Desktop Application.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="rg-example-virtualdesktop",
            location="West Europe")
        pooledbreadthfirst = azure.desktopvirtualization.HostPool("pooledbreadthfirst",
            name="pooledbreadthfirst",
            location=example.location,
            resource_group_name=example.name,
            type="Pooled",
            load_balancer_type="BreadthFirst")
        personalautomatic = azure.desktopvirtualization.HostPool("personalautomatic",
            name="personalautomatic",
            location=example.location,
            resource_group_name=example.name,
            type="Personal",
            personal_desktop_assignment_type="Automatic",
            load_balancer_type="BreadthFirst")
        remoteapp = azure.desktopvirtualization.ApplicationGroup("remoteapp",
            name="acctag",
            location=example.location,
            resource_group_name=example.name,
            type="RemoteApp",
            host_pool_id=pooledbreadthfirst.id,
            friendly_name="TestAppGroup",
            description="Acceptance Test: An application group")
        chrome = azure.desktopvirtualization.Application("chrome",
            name="googlechrome",
            application_group_id=remoteapp.id,
            friendly_name="Google Chrome",
            description="Chromium based web browser",
            path="C:\\\\Program Files\\\\Google\\\\Chrome\\\\Application\\\\chrome.exe",
            command_line_argument_policy="DoNotAllow",
            command_line_arguments="--incognito",
            show_in_portal=False,
            icon_path="C:\\\\Program Files\\\\Google\\\\Chrome\\\\Application\\\\chrome.exe",
            icon_index=0)
        ```

        ## Import

        Virtual Desktop Application can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:desktopvirtualization/application:Application example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/myGroup1/providers/Microsoft.DesktopVirtualization/applicationGroups/myapplicationgroup/applications/myapplication
        ```

        :param str resource_name: The name of the resource.
        :param ApplicationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_group_id: Optional[pulumi.Input[str]] = None,
                 command_line_argument_policy: Optional[pulumi.Input[str]] = None,
                 command_line_arguments: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 friendly_name: Optional[pulumi.Input[str]] = None,
                 icon_index: Optional[pulumi.Input[int]] = None,
                 icon_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 show_in_portal: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationArgs.__new__(ApplicationArgs)

            if application_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'application_group_id'")
            __props__.__dict__["application_group_id"] = application_group_id
            if command_line_argument_policy is None and not opts.urn:
                raise TypeError("Missing required property 'command_line_argument_policy'")
            __props__.__dict__["command_line_argument_policy"] = command_line_argument_policy
            __props__.__dict__["command_line_arguments"] = command_line_arguments
            __props__.__dict__["description"] = description
            __props__.__dict__["friendly_name"] = friendly_name
            __props__.__dict__["icon_index"] = icon_index
            __props__.__dict__["icon_path"] = icon_path
            __props__.__dict__["name"] = name
            if path is None and not opts.urn:
                raise TypeError("Missing required property 'path'")
            __props__.__dict__["path"] = path
            __props__.__dict__["show_in_portal"] = show_in_portal
        super(Application, __self__).__init__(
            'azure:desktopvirtualization/application:Application',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_group_id: Optional[pulumi.Input[str]] = None,
            command_line_argument_policy: Optional[pulumi.Input[str]] = None,
            command_line_arguments: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            friendly_name: Optional[pulumi.Input[str]] = None,
            icon_index: Optional[pulumi.Input[int]] = None,
            icon_path: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            path: Optional[pulumi.Input[str]] = None,
            show_in_portal: Optional[pulumi.Input[bool]] = None) -> 'Application':
        """
        Get an existing Application resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_group_id: Resource ID for a Virtual Desktop Application Group to associate with the Virtual Desktop Application. Changing this forces a new resource to be created.
        :param pulumi.Input[str] command_line_argument_policy: Specifies whether this published application can be launched with command line arguments provided by the client, command line arguments specified at publish time, or no command line arguments at all. Possible values include: `DoNotAllow`, `Allow`, `Require`.
        :param pulumi.Input[str] command_line_arguments: Command Line Arguments for Virtual Desktop Application.
        :param pulumi.Input[str] description: Option to set a description for the Virtual Desktop Application.
        :param pulumi.Input[str] friendly_name: Option to set a friendly name for the Virtual Desktop Application.
        :param pulumi.Input[int] icon_index: The index of the icon you wish to use.
        :param pulumi.Input[str] icon_path: Specifies the path for an icon which will be used for this Virtual Desktop Application.
        :param pulumi.Input[str] name: The name of the Virtual Desktop Application. Changing the name forces a new resource to be created.
        :param pulumi.Input[str] path: The file path location of the app on the Virtual Desktop OS.
        :param pulumi.Input[bool] show_in_portal: Specifies whether to show the RemoteApp program in the RD Web Access server.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationState.__new__(_ApplicationState)

        __props__.__dict__["application_group_id"] = application_group_id
        __props__.__dict__["command_line_argument_policy"] = command_line_argument_policy
        __props__.__dict__["command_line_arguments"] = command_line_arguments
        __props__.__dict__["description"] = description
        __props__.__dict__["friendly_name"] = friendly_name
        __props__.__dict__["icon_index"] = icon_index
        __props__.__dict__["icon_path"] = icon_path
        __props__.__dict__["name"] = name
        __props__.__dict__["path"] = path
        __props__.__dict__["show_in_portal"] = show_in_portal
        return Application(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="applicationGroupId")
    def application_group_id(self) -> pulumi.Output[str]:
        """
        Resource ID for a Virtual Desktop Application Group to associate with the Virtual Desktop Application. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_group_id")

    @property
    @pulumi.getter(name="commandLineArgumentPolicy")
    def command_line_argument_policy(self) -> pulumi.Output[str]:
        """
        Specifies whether this published application can be launched with command line arguments provided by the client, command line arguments specified at publish time, or no command line arguments at all. Possible values include: `DoNotAllow`, `Allow`, `Require`.
        """
        return pulumi.get(self, "command_line_argument_policy")

    @property
    @pulumi.getter(name="commandLineArguments")
    def command_line_arguments(self) -> pulumi.Output[Optional[str]]:
        """
        Command Line Arguments for Virtual Desktop Application.
        """
        return pulumi.get(self, "command_line_arguments")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Option to set a description for the Virtual Desktop Application.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="friendlyName")
    def friendly_name(self) -> pulumi.Output[str]:
        """
        Option to set a friendly name for the Virtual Desktop Application.
        """
        return pulumi.get(self, "friendly_name")

    @property
    @pulumi.getter(name="iconIndex")
    def icon_index(self) -> pulumi.Output[Optional[int]]:
        """
        The index of the icon you wish to use.
        """
        return pulumi.get(self, "icon_index")

    @property
    @pulumi.getter(name="iconPath")
    def icon_path(self) -> pulumi.Output[str]:
        """
        Specifies the path for an icon which will be used for this Virtual Desktop Application.
        """
        return pulumi.get(self, "icon_path")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Virtual Desktop Application. Changing the name forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def path(self) -> pulumi.Output[str]:
        """
        The file path location of the app on the Virtual Desktop OS.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="showInPortal")
    def show_in_portal(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to show the RemoteApp program in the RD Web Access server.
        """
        return pulumi.get(self, "show_in_portal")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ServiceCorArgs',
    'ServiceCorArgsDict',
    'ServiceIdentityArgs',
    'ServiceIdentityArgsDict',
    'ServiceLiveTraceArgs',
    'ServiceLiveTraceArgsDict',
    'ServiceNetworkAclPrivateEndpointArgs',
    'ServiceNetworkAclPrivateEndpointArgsDict',
    'ServiceNetworkAclPublicNetworkArgs',
    'ServiceNetworkAclPublicNetworkArgsDict',
    'ServiceSkuArgs',
    'ServiceSkuArgsDict',
    'ServiceUpstreamEndpointArgs',
    'ServiceUpstreamEndpointArgsDict',
]

MYPY = False

if not MYPY:
    class ServiceCorArgsDict(TypedDict):
        allowed_origins: pulumi.Input[Sequence[pulumi.Input[str]]]
        """
        A list of origins which should be able to make cross-origin calls. `*` can be used to allow all calls.
        """
elif False:
    ServiceCorArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceCorArgs:
    def __init__(__self__, *,
                 allowed_origins: pulumi.Input[Sequence[pulumi.Input[str]]]):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_origins: A list of origins which should be able to make cross-origin calls. `*` can be used to allow all calls.
        """
        pulumi.set(__self__, "allowed_origins", allowed_origins)

    @property
    @pulumi.getter(name="allowedOrigins")
    def allowed_origins(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        A list of origins which should be able to make cross-origin calls. `*` can be used to allow all calls.
        """
        return pulumi.get(self, "allowed_origins")

    @allowed_origins.setter
    def allowed_origins(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "allowed_origins", value)


if not MYPY:
    class ServiceIdentityArgsDict(TypedDict):
        type: pulumi.Input[str]
        """
        Specifies the type of Managed Service Identity that should be configured on this signalR. Possible values are `SystemAssigned`, `UserAssigned`.
        """
        identity_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        Specifies a list of User Assigned Managed Identity IDs to be assigned to this signalR.

        > **NOTE:** This is required when `type` is set to `UserAssigned`
        """
        principal_id: NotRequired[pulumi.Input[str]]
        tenant_id: NotRequired[pulumi.Input[str]]
elif False:
    ServiceIdentityArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceIdentityArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 identity_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 principal_id: Optional[pulumi.Input[str]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] type: Specifies the type of Managed Service Identity that should be configured on this signalR. Possible values are `SystemAssigned`, `UserAssigned`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] identity_ids: Specifies a list of User Assigned Managed Identity IDs to be assigned to this signalR.
               
               > **NOTE:** This is required when `type` is set to `UserAssigned`
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Specifies the type of Managed Service Identity that should be configured on this signalR. Possible values are `SystemAssigned`, `UserAssigned`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies a list of User Assigned Managed Identity IDs to be assigned to this signalR.

        > **NOTE:** This is required when `type` is set to `UserAssigned`
        """
        return pulumi.get(self, "identity_ids")

    @identity_ids.setter
    def identity_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "identity_ids", value)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)


if not MYPY:
    class ServiceLiveTraceArgsDict(TypedDict):
        connectivity_logs_enabled: NotRequired[pulumi.Input[bool]]
        """
        Whether the log category `ConnectivityLogs` is enabled? Defaults to `true`
        """
        enabled: NotRequired[pulumi.Input[bool]]
        """
        Whether the live trace is enabled? Defaults to `true`.
        """
        http_request_logs_enabled: NotRequired[pulumi.Input[bool]]
        """
        Whether the log category `HttpRequestLogs` is enabled? Defaults to `true`
        """
        messaging_logs_enabled: NotRequired[pulumi.Input[bool]]
        """
        Whether the log category `MessagingLogs` is enabled? Defaults to `true`
        """
elif False:
    ServiceLiveTraceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceLiveTraceArgs:
    def __init__(__self__, *,
                 connectivity_logs_enabled: Optional[pulumi.Input[bool]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 http_request_logs_enabled: Optional[pulumi.Input[bool]] = None,
                 messaging_logs_enabled: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[bool] connectivity_logs_enabled: Whether the log category `ConnectivityLogs` is enabled? Defaults to `true`
        :param pulumi.Input[bool] enabled: Whether the live trace is enabled? Defaults to `true`.
        :param pulumi.Input[bool] http_request_logs_enabled: Whether the log category `HttpRequestLogs` is enabled? Defaults to `true`
        :param pulumi.Input[bool] messaging_logs_enabled: Whether the log category `MessagingLogs` is enabled? Defaults to `true`
        """
        if connectivity_logs_enabled is not None:
            pulumi.set(__self__, "connectivity_logs_enabled", connectivity_logs_enabled)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if http_request_logs_enabled is not None:
            pulumi.set(__self__, "http_request_logs_enabled", http_request_logs_enabled)
        if messaging_logs_enabled is not None:
            pulumi.set(__self__, "messaging_logs_enabled", messaging_logs_enabled)

    @property
    @pulumi.getter(name="connectivityLogsEnabled")
    def connectivity_logs_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the log category `ConnectivityLogs` is enabled? Defaults to `true`
        """
        return pulumi.get(self, "connectivity_logs_enabled")

    @connectivity_logs_enabled.setter
    def connectivity_logs_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "connectivity_logs_enabled", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the live trace is enabled? Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="httpRequestLogsEnabled")
    def http_request_logs_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the log category `HttpRequestLogs` is enabled? Defaults to `true`
        """
        return pulumi.get(self, "http_request_logs_enabled")

    @http_request_logs_enabled.setter
    def http_request_logs_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "http_request_logs_enabled", value)

    @property
    @pulumi.getter(name="messagingLogsEnabled")
    def messaging_logs_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the log category `MessagingLogs` is enabled? Defaults to `true`
        """
        return pulumi.get(self, "messaging_logs_enabled")

    @messaging_logs_enabled.setter
    def messaging_logs_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "messaging_logs_enabled", value)


if not MYPY:
    class ServiceNetworkAclPrivateEndpointArgsDict(TypedDict):
        id: pulumi.Input[str]
        """
        The ID of the Private Endpoint which is based on the SignalR service.
        """
        allowed_request_types: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The allowed request types for the Private Endpoint Connection. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Allow`, `allowed_request_types`cannot be set.
        """
        denied_request_types: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The denied request types for the Private Endpoint Connection. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Deny`, `denied_request_types`cannot be set.

        > **Note:** `allowed_request_types` - (Optional) and `denied_request_types` cannot be set together.
        """
elif False:
    ServiceNetworkAclPrivateEndpointArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceNetworkAclPrivateEndpointArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[str],
                 allowed_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 denied_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[str] id: The ID of the Private Endpoint which is based on the SignalR service.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_request_types: The allowed request types for the Private Endpoint Connection. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.
               
               > **Note:** When `default_action` is `Allow`, `allowed_request_types`cannot be set.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] denied_request_types: The denied request types for the Private Endpoint Connection. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.
               
               > **Note:** When `default_action` is `Deny`, `denied_request_types`cannot be set.
               
               > **Note:** `allowed_request_types` - (Optional) and `denied_request_types` cannot be set together.
        """
        pulumi.set(__self__, "id", id)
        if allowed_request_types is not None:
            pulumi.set(__self__, "allowed_request_types", allowed_request_types)
        if denied_request_types is not None:
            pulumi.set(__self__, "denied_request_types", denied_request_types)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        """
        The ID of the Private Endpoint which is based on the SignalR service.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="allowedRequestTypes")
    def allowed_request_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The allowed request types for the Private Endpoint Connection. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Allow`, `allowed_request_types`cannot be set.
        """
        return pulumi.get(self, "allowed_request_types")

    @allowed_request_types.setter
    def allowed_request_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "allowed_request_types", value)

    @property
    @pulumi.getter(name="deniedRequestTypes")
    def denied_request_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The denied request types for the Private Endpoint Connection. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Deny`, `denied_request_types`cannot be set.

        > **Note:** `allowed_request_types` - (Optional) and `denied_request_types` cannot be set together.
        """
        return pulumi.get(self, "denied_request_types")

    @denied_request_types.setter
    def denied_request_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "denied_request_types", value)


if not MYPY:
    class ServiceNetworkAclPublicNetworkArgsDict(TypedDict):
        allowed_request_types: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The allowed request types for the public network. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Allow`, `allowed_request_types`cannot be set.
        """
        denied_request_types: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The denied request types for the public network. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Deny`, `denied_request_types`cannot be set.

        > **Note:** `allowed_request_types` - (Optional) and `denied_request_types` cannot be set together.
        """
elif False:
    ServiceNetworkAclPublicNetworkArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceNetworkAclPublicNetworkArgs:
    def __init__(__self__, *,
                 allowed_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 denied_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_request_types: The allowed request types for the public network. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.
               
               > **Note:** When `default_action` is `Allow`, `allowed_request_types`cannot be set.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] denied_request_types: The denied request types for the public network. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.
               
               > **Note:** When `default_action` is `Deny`, `denied_request_types`cannot be set.
               
               > **Note:** `allowed_request_types` - (Optional) and `denied_request_types` cannot be set together.
        """
        if allowed_request_types is not None:
            pulumi.set(__self__, "allowed_request_types", allowed_request_types)
        if denied_request_types is not None:
            pulumi.set(__self__, "denied_request_types", denied_request_types)

    @property
    @pulumi.getter(name="allowedRequestTypes")
    def allowed_request_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The allowed request types for the public network. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Allow`, `allowed_request_types`cannot be set.
        """
        return pulumi.get(self, "allowed_request_types")

    @allowed_request_types.setter
    def allowed_request_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "allowed_request_types", value)

    @property
    @pulumi.getter(name="deniedRequestTypes")
    def denied_request_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The denied request types for the public network. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Deny`, `denied_request_types`cannot be set.

        > **Note:** `allowed_request_types` - (Optional) and `denied_request_types` cannot be set together.
        """
        return pulumi.get(self, "denied_request_types")

    @denied_request_types.setter
    def denied_request_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "denied_request_types", value)


if not MYPY:
    class ServiceSkuArgsDict(TypedDict):
        capacity: pulumi.Input[int]
        """
        Specifies the number of units associated with this SignalR service. Valid values are `1`, `2`, `3`, `4`, `5`, `6`, `7`, `8`, `9`, `10`, `20`, `30`, `40`, `50`, `60`, `70`, `80`, `90`, `100`, `200`, `300`, `400`, `500`, `600`, `700`, `800`, `900` and `1000`.

        > **NOTE:** The valid capacity range for sku `Free_F1` is `1`, for sku `Premium_P2` is from `100` to `1000`, and from `1` to `100` for sku `Standard_S1` and `Premium_P1`.
        """
        name: pulumi.Input[str]
        """
        Specifies which tier to use. Valid values are `Free_F1`, `Standard_S1`, `Premium_P1` and `Premium_P2`.
        """
elif False:
    ServiceSkuArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceSkuArgs:
    def __init__(__self__, *,
                 capacity: pulumi.Input[int],
                 name: pulumi.Input[str]):
        """
        :param pulumi.Input[int] capacity: Specifies the number of units associated with this SignalR service. Valid values are `1`, `2`, `3`, `4`, `5`, `6`, `7`, `8`, `9`, `10`, `20`, `30`, `40`, `50`, `60`, `70`, `80`, `90`, `100`, `200`, `300`, `400`, `500`, `600`, `700`, `800`, `900` and `1000`.
               
               > **NOTE:** The valid capacity range for sku `Free_F1` is `1`, for sku `Premium_P2` is from `100` to `1000`, and from `1` to `100` for sku `Standard_S1` and `Premium_P1`.
        :param pulumi.Input[str] name: Specifies which tier to use. Valid values are `Free_F1`, `Standard_S1`, `Premium_P1` and `Premium_P2`.
        """
        pulumi.set(__self__, "capacity", capacity)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def capacity(self) -> pulumi.Input[int]:
        """
        Specifies the number of units associated with this SignalR service. Valid values are `1`, `2`, `3`, `4`, `5`, `6`, `7`, `8`, `9`, `10`, `20`, `30`, `40`, `50`, `60`, `70`, `80`, `90`, `100`, `200`, `300`, `400`, `500`, `600`, `700`, `800`, `900` and `1000`.

        > **NOTE:** The valid capacity range for sku `Free_F1` is `1`, for sku `Premium_P2` is from `100` to `1000`, and from `1` to `100` for sku `Standard_S1` and `Premium_P1`.
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: pulumi.Input[int]):
        pulumi.set(self, "capacity", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Specifies which tier to use. Valid values are `Free_F1`, `Standard_S1`, `Premium_P1` and `Premium_P2`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)


if not MYPY:
    class ServiceUpstreamEndpointArgsDict(TypedDict):
        category_patterns: pulumi.Input[Sequence[pulumi.Input[str]]]
        """
        The categories to match on, or `*` for all.
        """
        event_patterns: pulumi.Input[Sequence[pulumi.Input[str]]]
        """
        The events to match on, or `*` for all.
        """
        hub_patterns: pulumi.Input[Sequence[pulumi.Input[str]]]
        """
        The hubs to match on, or `*` for all.
        """
        url_template: pulumi.Input[str]
        """
        The upstream URL Template. This can be a url or a template such as `http://host.com/{hub}/api/{category}/{event}`.
        """
        user_assigned_identity_id: NotRequired[pulumi.Input[str]]
        """
        Specifies the Managed Identity IDs to be assigned to this signalR upstream setting by using resource uuid as both system assigned and user assigned identity is supported.
        """
elif False:
    ServiceUpstreamEndpointArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceUpstreamEndpointArgs:
    def __init__(__self__, *,
                 category_patterns: pulumi.Input[Sequence[pulumi.Input[str]]],
                 event_patterns: pulumi.Input[Sequence[pulumi.Input[str]]],
                 hub_patterns: pulumi.Input[Sequence[pulumi.Input[str]]],
                 url_template: pulumi.Input[str],
                 user_assigned_identity_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] category_patterns: The categories to match on, or `*` for all.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] event_patterns: The events to match on, or `*` for all.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] hub_patterns: The hubs to match on, or `*` for all.
        :param pulumi.Input[str] url_template: The upstream URL Template. This can be a url or a template such as `http://host.com/{hub}/api/{category}/{event}`.
        :param pulumi.Input[str] user_assigned_identity_id: Specifies the Managed Identity IDs to be assigned to this signalR upstream setting by using resource uuid as both system assigned and user assigned identity is supported.
        """
        pulumi.set(__self__, "category_patterns", category_patterns)
        pulumi.set(__self__, "event_patterns", event_patterns)
        pulumi.set(__self__, "hub_patterns", hub_patterns)
        pulumi.set(__self__, "url_template", url_template)
        if user_assigned_identity_id is not None:
            pulumi.set(__self__, "user_assigned_identity_id", user_assigned_identity_id)

    @property
    @pulumi.getter(name="categoryPatterns")
    def category_patterns(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The categories to match on, or `*` for all.
        """
        return pulumi.get(self, "category_patterns")

    @category_patterns.setter
    def category_patterns(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "category_patterns", value)

    @property
    @pulumi.getter(name="eventPatterns")
    def event_patterns(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The events to match on, or `*` for all.
        """
        return pulumi.get(self, "event_patterns")

    @event_patterns.setter
    def event_patterns(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "event_patterns", value)

    @property
    @pulumi.getter(name="hubPatterns")
    def hub_patterns(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The hubs to match on, or `*` for all.
        """
        return pulumi.get(self, "hub_patterns")

    @hub_patterns.setter
    def hub_patterns(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "hub_patterns", value)

    @property
    @pulumi.getter(name="urlTemplate")
    def url_template(self) -> pulumi.Input[str]:
        """
        The upstream URL Template. This can be a url or a template such as `http://host.com/{hub}/api/{category}/{event}`.
        """
        return pulumi.get(self, "url_template")

    @url_template.setter
    def url_template(self, value: pulumi.Input[str]):
        pulumi.set(self, "url_template", value)

    @property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the Managed Identity IDs to be assigned to this signalR upstream setting by using resource uuid as both system assigned and user assigned identity is supported.
        """
        return pulumi.get(self, "user_assigned_identity_id")

    @user_assigned_identity_id.setter
    def user_assigned_identity_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_assigned_identity_id", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SqlFunctionArgs', 'SqlFunction']

@pulumi.input_type
class SqlFunctionArgs:
    def __init__(__self__, *,
                 body: pulumi.Input[str],
                 container_id: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SqlFunction resource.
        :param pulumi.Input[str] body: Body of the User Defined Function.
        :param pulumi.Input[str] container_id: The id of the Cosmos DB SQL Container to create the SQL User Defined Function within. Changing this forces a new SQL User Defined Function to be created.
        :param pulumi.Input[str] name: The name which should be used for this SQL User Defined Function. Changing this forces a new SQL User Defined Function to be created.
        """
        pulumi.set(__self__, "body", body)
        pulumi.set(__self__, "container_id", container_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def body(self) -> pulumi.Input[str]:
        """
        Body of the User Defined Function.
        """
        return pulumi.get(self, "body")

    @body.setter
    def body(self, value: pulumi.Input[str]):
        pulumi.set(self, "body", value)

    @property
    @pulumi.getter(name="containerId")
    def container_id(self) -> pulumi.Input[str]:
        """
        The id of the Cosmos DB SQL Container to create the SQL User Defined Function within. Changing this forces a new SQL User Defined Function to be created.
        """
        return pulumi.get(self, "container_id")

    @container_id.setter
    def container_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "container_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this SQL User Defined Function. Changing this forces a new SQL User Defined Function to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _SqlFunctionState:
    def __init__(__self__, *,
                 body: Optional[pulumi.Input[str]] = None,
                 container_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SqlFunction resources.
        :param pulumi.Input[str] body: Body of the User Defined Function.
        :param pulumi.Input[str] container_id: The id of the Cosmos DB SQL Container to create the SQL User Defined Function within. Changing this forces a new SQL User Defined Function to be created.
        :param pulumi.Input[str] name: The name which should be used for this SQL User Defined Function. Changing this forces a new SQL User Defined Function to be created.
        """
        if body is not None:
            pulumi.set(__self__, "body", body)
        if container_id is not None:
            pulumi.set(__self__, "container_id", container_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def body(self) -> Optional[pulumi.Input[str]]:
        """
        Body of the User Defined Function.
        """
        return pulumi.get(self, "body")

    @body.setter
    def body(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "body", value)

    @property
    @pulumi.getter(name="containerId")
    def container_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the Cosmos DB SQL Container to create the SQL User Defined Function within. Changing this forces a new SQL User Defined Function to be created.
        """
        return pulumi.get(self, "container_id")

    @container_id.setter
    def container_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "container_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this SQL User Defined Function. Changing this forces a new SQL User Defined Function to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class SqlFunction(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 body: Optional[pulumi.Input[str]] = None,
                 container_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages an SQL User Defined Function.

        ## Import

        SQL User Defined Functions can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:cosmosdb/sqlFunction:SqlFunction example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.DocumentDB/databaseAccounts/account1/sqlDatabases/database1/containers/container1/userDefinedFunctions/userDefinedFunction1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] body: Body of the User Defined Function.
        :param pulumi.Input[str] container_id: The id of the Cosmos DB SQL Container to create the SQL User Defined Function within. Changing this forces a new SQL User Defined Function to be created.
        :param pulumi.Input[str] name: The name which should be used for this SQL User Defined Function. Changing this forces a new SQL User Defined Function to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SqlFunctionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an SQL User Defined Function.

        ## Import

        SQL User Defined Functions can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:cosmosdb/sqlFunction:SqlFunction example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.DocumentDB/databaseAccounts/account1/sqlDatabases/database1/containers/container1/userDefinedFunctions/userDefinedFunction1
        ```

        :param str resource_name: The name of the resource.
        :param SqlFunctionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SqlFunctionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 body: Optional[pulumi.Input[str]] = None,
                 container_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SqlFunctionArgs.__new__(SqlFunctionArgs)

            if body is None and not opts.urn:
                raise TypeError("Missing required property 'body'")
            __props__.__dict__["body"] = body
            if container_id is None and not opts.urn:
                raise TypeError("Missing required property 'container_id'")
            __props__.__dict__["container_id"] = container_id
            __props__.__dict__["name"] = name
        super(SqlFunction, __self__).__init__(
            'azure:cosmosdb/sqlFunction:SqlFunction',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            body: Optional[pulumi.Input[str]] = None,
            container_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'SqlFunction':
        """
        Get an existing SqlFunction resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] body: Body of the User Defined Function.
        :param pulumi.Input[str] container_id: The id of the Cosmos DB SQL Container to create the SQL User Defined Function within. Changing this forces a new SQL User Defined Function to be created.
        :param pulumi.Input[str] name: The name which should be used for this SQL User Defined Function. Changing this forces a new SQL User Defined Function to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SqlFunctionState.__new__(_SqlFunctionState)

        __props__.__dict__["body"] = body
        __props__.__dict__["container_id"] = container_id
        __props__.__dict__["name"] = name
        return SqlFunction(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def body(self) -> pulumi.Output[str]:
        """
        Body of the User Defined Function.
        """
        return pulumi.get(self, "body")

    @property
    @pulumi.getter(name="containerId")
    def container_id(self) -> pulumi.Output[str]:
        """
        The id of the Cosmos DB SQL Container to create the SQL User Defined Function within. Changing this forces a new SQL User Defined Function to be created.
        """
        return pulumi.get(self, "container_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name which should be used for this SQL User Defined Function. Changing this forces a new SQL User Defined Function to be created.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ChannelDirectLineSiteArgs',
    'ChannelDirectLineSiteArgsDict',
    'ChannelFacebookPageArgs',
    'ChannelFacebookPageArgsDict',
    'ChannelLineLineChannelArgs',
    'ChannelLineLineChannelArgsDict',
    'ChannelWebChatSiteArgs',
    'ChannelWebChatSiteArgsDict',
]

MYPY = False

if not MYPY:
    class ChannelDirectLineSiteArgsDict(TypedDict):
        name: pulumi.Input[str]
        """
        The name of the site
        """
        enabled: NotRequired[pulumi.Input[bool]]
        """
        Enables/Disables this site. Defaults to `true`.
        """
        endpoint_parameters_enabled: NotRequired[pulumi.Input[bool]]
        """
        Is the endpoint parameters enabled for this site?
        """
        enhanced_authentication_enabled: NotRequired[pulumi.Input[bool]]
        """
        Enables additional security measures for this site, see [Enhanced Directline Authentication Features](https://blog.botframework.com/2018/09/25/enhanced-direct-line-authentication-features). Disabled by default.
        """
        id: NotRequired[pulumi.Input[str]]
        """
        Id for the site
        """
        key: NotRequired[pulumi.Input[str]]
        """
        Primary key for accessing this site
        """
        key2: NotRequired[pulumi.Input[str]]
        """
        Secondary key for accessing this site
        """
        storage_enabled: NotRequired[pulumi.Input[bool]]
        """
        Is the storage site enabled for detailed logging? Defaults to `true`.
        """
        trusted_origins: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        This field is required when `is_secure_site_enabled` is enabled. Determines which origins can establish a Directline conversation for this site.
        """
        user_upload_enabled: NotRequired[pulumi.Input[bool]]
        """
        Is the user upload enabled for this site? Defaults to `true`.
        """
        v1_allowed: NotRequired[pulumi.Input[bool]]
        """
        Enables v1 of the Directline protocol for this site. Defaults to `true`.
        """
        v3_allowed: NotRequired[pulumi.Input[bool]]
        """
        Enables v3 of the Directline protocol for this site. Defaults to `true`.
        """
elif False:
    ChannelDirectLineSiteArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ChannelDirectLineSiteArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 enabled: Optional[pulumi.Input[bool]] = None,
                 endpoint_parameters_enabled: Optional[pulumi.Input[bool]] = None,
                 enhanced_authentication_enabled: Optional[pulumi.Input[bool]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 key2: Optional[pulumi.Input[str]] = None,
                 storage_enabled: Optional[pulumi.Input[bool]] = None,
                 trusted_origins: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_upload_enabled: Optional[pulumi.Input[bool]] = None,
                 v1_allowed: Optional[pulumi.Input[bool]] = None,
                 v3_allowed: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[str] name: The name of the site
        :param pulumi.Input[bool] enabled: Enables/Disables this site. Defaults to `true`.
        :param pulumi.Input[bool] endpoint_parameters_enabled: Is the endpoint parameters enabled for this site?
        :param pulumi.Input[bool] enhanced_authentication_enabled: Enables additional security measures for this site, see [Enhanced Directline Authentication Features](https://blog.botframework.com/2018/09/25/enhanced-direct-line-authentication-features). Disabled by default.
        :param pulumi.Input[str] id: Id for the site
        :param pulumi.Input[str] key: Primary key for accessing this site
        :param pulumi.Input[str] key2: Secondary key for accessing this site
        :param pulumi.Input[bool] storage_enabled: Is the storage site enabled for detailed logging? Defaults to `true`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] trusted_origins: This field is required when `is_secure_site_enabled` is enabled. Determines which origins can establish a Directline conversation for this site.
        :param pulumi.Input[bool] user_upload_enabled: Is the user upload enabled for this site? Defaults to `true`.
        :param pulumi.Input[bool] v1_allowed: Enables v1 of the Directline protocol for this site. Defaults to `true`.
        :param pulumi.Input[bool] v3_allowed: Enables v3 of the Directline protocol for this site. Defaults to `true`.
        """
        pulumi.set(__self__, "name", name)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if endpoint_parameters_enabled is not None:
            pulumi.set(__self__, "endpoint_parameters_enabled", endpoint_parameters_enabled)
        if enhanced_authentication_enabled is not None:
            pulumi.set(__self__, "enhanced_authentication_enabled", enhanced_authentication_enabled)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if key2 is not None:
            pulumi.set(__self__, "key2", key2)
        if storage_enabled is not None:
            pulumi.set(__self__, "storage_enabled", storage_enabled)
        if trusted_origins is not None:
            pulumi.set(__self__, "trusted_origins", trusted_origins)
        if user_upload_enabled is not None:
            pulumi.set(__self__, "user_upload_enabled", user_upload_enabled)
        if v1_allowed is not None:
            pulumi.set(__self__, "v1_allowed", v1_allowed)
        if v3_allowed is not None:
            pulumi.set(__self__, "v3_allowed", v3_allowed)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        The name of the site
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables/Disables this site. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="endpointParametersEnabled")
    def endpoint_parameters_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is the endpoint parameters enabled for this site?
        """
        return pulumi.get(self, "endpoint_parameters_enabled")

    @endpoint_parameters_enabled.setter
    def endpoint_parameters_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "endpoint_parameters_enabled", value)

    @property
    @pulumi.getter(name="enhancedAuthenticationEnabled")
    def enhanced_authentication_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables additional security measures for this site, see [Enhanced Directline Authentication Features](https://blog.botframework.com/2018/09/25/enhanced-direct-line-authentication-features). Disabled by default.
        """
        return pulumi.get(self, "enhanced_authentication_enabled")

    @enhanced_authentication_enabled.setter
    def enhanced_authentication_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enhanced_authentication_enabled", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        Id for the site
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        Primary key for accessing this site
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def key2(self) -> Optional[pulumi.Input[str]]:
        """
        Secondary key for accessing this site
        """
        return pulumi.get(self, "key2")

    @key2.setter
    def key2(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key2", value)

    @property
    @pulumi.getter(name="storageEnabled")
    def storage_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is the storage site enabled for detailed logging? Defaults to `true`.
        """
        return pulumi.get(self, "storage_enabled")

    @storage_enabled.setter
    def storage_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "storage_enabled", value)

    @property
    @pulumi.getter(name="trustedOrigins")
    def trusted_origins(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        This field is required when `is_secure_site_enabled` is enabled. Determines which origins can establish a Directline conversation for this site.
        """
        return pulumi.get(self, "trusted_origins")

    @trusted_origins.setter
    def trusted_origins(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "trusted_origins", value)

    @property
    @pulumi.getter(name="userUploadEnabled")
    def user_upload_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is the user upload enabled for this site? Defaults to `true`.
        """
        return pulumi.get(self, "user_upload_enabled")

    @user_upload_enabled.setter
    def user_upload_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "user_upload_enabled", value)

    @property
    @pulumi.getter(name="v1Allowed")
    def v1_allowed(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables v1 of the Directline protocol for this site. Defaults to `true`.
        """
        return pulumi.get(self, "v1_allowed")

    @v1_allowed.setter
    def v1_allowed(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "v1_allowed", value)

    @property
    @pulumi.getter(name="v3Allowed")
    def v3_allowed(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables v3 of the Directline protocol for this site. Defaults to `true`.
        """
        return pulumi.get(self, "v3_allowed")

    @v3_allowed.setter
    def v3_allowed(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "v3_allowed", value)


if not MYPY:
    class ChannelFacebookPageArgsDict(TypedDict):
        access_token: pulumi.Input[str]
        """
        The Facebook Page Access Token for the Facebook Channel.
        """
        id: pulumi.Input[str]
        """
        The Facebook Page ID for the Facebook Channel.
        """
elif False:
    ChannelFacebookPageArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ChannelFacebookPageArgs:
    def __init__(__self__, *,
                 access_token: pulumi.Input[str],
                 id: pulumi.Input[str]):
        """
        :param pulumi.Input[str] access_token: The Facebook Page Access Token for the Facebook Channel.
        :param pulumi.Input[str] id: The Facebook Page ID for the Facebook Channel.
        """
        pulumi.set(__self__, "access_token", access_token)
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> pulumi.Input[str]:
        """
        The Facebook Page Access Token for the Facebook Channel.
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: pulumi.Input[str]):
        pulumi.set(self, "access_token", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        """
        The Facebook Page ID for the Facebook Channel.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)


if not MYPY:
    class ChannelLineLineChannelArgsDict(TypedDict):
        access_token: pulumi.Input[str]
        """
        The access token which is used to call the Line Channel API.
        """
        secret: pulumi.Input[str]
        """
        The secret which is used to access the Line Channel.
        """
elif False:
    ChannelLineLineChannelArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ChannelLineLineChannelArgs:
    def __init__(__self__, *,
                 access_token: pulumi.Input[str],
                 secret: pulumi.Input[str]):
        """
        :param pulumi.Input[str] access_token: The access token which is used to call the Line Channel API.
        :param pulumi.Input[str] secret: The secret which is used to access the Line Channel.
        """
        pulumi.set(__self__, "access_token", access_token)
        pulumi.set(__self__, "secret", secret)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> pulumi.Input[str]:
        """
        The access token which is used to call the Line Channel API.
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: pulumi.Input[str]):
        pulumi.set(self, "access_token", value)

    @property
    @pulumi.getter
    def secret(self) -> pulumi.Input[str]:
        """
        The secret which is used to access the Line Channel.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: pulumi.Input[str]):
        pulumi.set(self, "secret", value)


if not MYPY:
    class ChannelWebChatSiteArgsDict(TypedDict):
        name: pulumi.Input[str]
        """
        The name of the site.
        """
        endpoint_parameters_enabled: NotRequired[pulumi.Input[bool]]
        """
        Is the endpoint parameters enabled for this site?
        """
        storage_enabled: NotRequired[pulumi.Input[bool]]
        """
        Is the storage site enabled for detailed logging? Defaults to `true`.
        """
        user_upload_enabled: NotRequired[pulumi.Input[bool]]
        """
        Is the user upload enabled for this site? Defaults to `true`.
        """
elif False:
    ChannelWebChatSiteArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ChannelWebChatSiteArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 endpoint_parameters_enabled: Optional[pulumi.Input[bool]] = None,
                 storage_enabled: Optional[pulumi.Input[bool]] = None,
                 user_upload_enabled: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[str] name: The name of the site.
        :param pulumi.Input[bool] endpoint_parameters_enabled: Is the endpoint parameters enabled for this site?
        :param pulumi.Input[bool] storage_enabled: Is the storage site enabled for detailed logging? Defaults to `true`.
        :param pulumi.Input[bool] user_upload_enabled: Is the user upload enabled for this site? Defaults to `true`.
        """
        pulumi.set(__self__, "name", name)
        if endpoint_parameters_enabled is not None:
            pulumi.set(__self__, "endpoint_parameters_enabled", endpoint_parameters_enabled)
        if storage_enabled is not None:
            pulumi.set(__self__, "storage_enabled", storage_enabled)
        if user_upload_enabled is not None:
            pulumi.set(__self__, "user_upload_enabled", user_upload_enabled)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        The name of the site.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="endpointParametersEnabled")
    def endpoint_parameters_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is the endpoint parameters enabled for this site?
        """
        return pulumi.get(self, "endpoint_parameters_enabled")

    @endpoint_parameters_enabled.setter
    def endpoint_parameters_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "endpoint_parameters_enabled", value)

    @property
    @pulumi.getter(name="storageEnabled")
    def storage_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is the storage site enabled for detailed logging? Defaults to `true`.
        """
        return pulumi.get(self, "storage_enabled")

    @storage_enabled.setter
    def storage_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "storage_enabled", value)

    @property
    @pulumi.getter(name="userUploadEnabled")
    def user_upload_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is the user upload enabled for this site? Defaults to `true`.
        """
        return pulumi.get(self, "user_upload_enabled")

    @user_upload_enabled.setter
    def user_upload_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "user_upload_enabled", value)


